==> xml-extensions-4.10.0-sources.jar: de/alpharogroup/xml/sax/handler/BreakParsingException.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2007 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.xml.sax.handler;

/**
 * The Class BreakParsingException is thrown if the parse have to stop.
 *
 * @version 1.0
 * @author Asterios Raptis
 */
public class BreakParsingException extends RuntimeException
{

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 2829935952852650245L;

	/**
	 * Instantiates a new BreakParsingException.
	 */
	public BreakParsingException()
	{
		super();
	}

	/**
	 * Instantiates a new BreakParsingException.
	 *
	 * @param message
	 *            the message
	 */
	public BreakParsingException(final String message)
	{
		super(message);
	}

	/**
	 * Instantiates a new BreakParsingException.
	 *
	 * @param message
	 *            the message
	 * @param cause
	 *            the cause
	 */
	public BreakParsingException(final String message, final Throwable cause)
	{
		super(message, cause);
	}

	/**
	 * Instantiates a new BreakParsingException.
	 *
	 * @param cause
	 *            the cause
	 */
	public BreakParsingException(final Throwable cause)
	{
		super(cause);
	}

}

==> xml-extensions-4.14.0-sources.jar: de/alpharogroup/xml/sax/handler/BreakParsingException.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2007 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.xml.sax.handler;

/**
 * The class BreakParsingException is thrown if the parse have to stop.
 *
 * @version 1.0
 * @author Asterios Raptis
 */
public class BreakParsingException extends RuntimeException
{

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 2829935952852650245L;

	/**
	 * Instantiates a new BreakParsingException.
	 */
	public BreakParsingException()
	{
		super();
	}

	/**
	 * Instantiates a new BreakParsingException.
	 *
	 * @param message
	 *            the message
	 */
	public BreakParsingException(final String message)
	{
		super(message);
	}

	/**
	 * Instantiates a new BreakParsingException.
	 *
	 * @param message
	 *            the message
	 * @param cause
	 *            the cause
	 */
	public BreakParsingException(final String message, final Throwable cause)
	{
		super(message, cause);
	}

	/**
	 * Instantiates a new BreakParsingException.
	 *
	 * @param cause
	 *            the cause
	 */
	public BreakParsingException(final Throwable cause)
	{
		super(cause);
	}

}
